smrf package
============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   smrf.data
   smrf.distribute
   smrf.envphys
   smrf.framework
   smrf.output
   smrf.spatial
   smrf.utils

Module contents
---------------

.. automodule:: smrf
   :members:
   :undoc-members:
   :show-inheritance:
